<?php
/**
 * lontano functions and definitions.
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package lontano
 */

if ( ! function_exists( 'lontano_setup' ) ) :
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 */
function lontano_setup() {
	/*
	 * Make theme available for translation.
	 * Translations can be filed in the /languages/ directory.
	 * If you're building a theme based on lontano, use a find and replace
	 * to change 'lontano' to the name of your theme in all the template files.
	 */
	load_theme_textdomain( 'lontano', get_template_directory() . '/languages' );

	// Add default posts and comments RSS feed links to head.
	add_theme_support( 'automatic-feed-links' );

	/*
	 * Let WordPress manage the document title.
	 * By adding theme support, we declare that this theme does not use a
	 * hard-coded <title> tag in the document head, and expect WordPress to
	 * provide it for us.
	 */
	add_theme_support( 'title-tag' );
	
	add_theme_support( 'customize-selective-refresh-widgets' );
	
	add_theme_support( 'custom-logo', array(
		'height'      => 100,
		'width'       => 300,
		'flex-width' => true,
		'header-text' => array( 'site-title', 'site-description' ),
	) );

	/*
	 * Enable support for Post Thumbnails on posts and pages.
	 *
	 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
	 */
	add_theme_support( 'post-thumbnails' );
	add_image_size( 'lontano-normal-post' , 800, 9999);

	// This theme uses wp_nav_menu() in one location.
	register_nav_menus( array(
		'primary' => esc_html__( 'Primary', 'lontano' ),
	) );

	/*
	 * Switch default core markup for search form, comment form, and comments
	 * to output valid HTML5.
	 */
	add_theme_support( 'html5', array(
		'search-form',
		'comment-form',
		'comment-list',
		'gallery',
		'caption',
	) );

	/*
	 * Enable support for Post Formats.
	 * See https://developer.wordpress.org/themes/functionality/post-formats/
	 */
	add_theme_support( 'post-formats', array(
		'audio',
		'gallery',
		'video',
	) );

	// Set up the WordPress core custom background feature.
	add_theme_support( 'custom-background', apply_filters( 'lontano_custom_background_args', array(
		'default-color' => 'd8d8d8',
		'default-image' => '',
	) ) );
}
endif;
add_action( 'after_setup_theme', 'lontano_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function lontano_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'lontano_content_width', 720 );
}
add_action( 'after_setup_theme', 'lontano_content_width', 0 );

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function lontano_widgets_init() {
	register_sidebar( array(
		'name'          => esc_html__( 'Sidebar', 'lontano' ),
		'id'            => 'sidebar-1',
		'description'   => '',
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );
}
add_action( 'widgets_init', 'lontano_widgets_init' );

/**
 * Enqueue scripts and styles.
 */
function lontano_scripts() {
	wp_enqueue_style( 'lontano-style', get_stylesheet_uri(), array(), wp_get_theme()->get('Version') );
	wp_enqueue_style( 'font-awesome', get_template_directory_uri() .'/css/font-awesome.min.css', array(), '4.7.0');
	$query_args = array(
		'family' => 'Raleway:300,400,700%7CHind+Siliguri:300,400,700'
	);
	wp_enqueue_style( 'lontano-googlefonts', add_query_arg( $query_args, '//fonts.googleapis.com/css' ), array(), null );
	wp_enqueue_script( 'lontano-custom', get_template_directory_uri() . '/js/jquery.lontano.js', array('jquery'), wp_get_theme()->get('Version'), true );
	wp_enqueue_script( 'lontano-navigation', get_template_directory_uri() . '/js/navigation.js', array(), '20120206', true );
	wp_enqueue_script( 'lontano-skip-link-focus-fix', get_template_directory_uri() . '/js/skip-link-focus-fix.js', array(), '20130115', true );

	if (get_theme_mod('lontano_theme_options_showflashnews', '1') == 1) {
		wp_enqueue_script( 'lontano-newsTicker', get_template_directory_uri() . '/js/jquery.newsTicker.min.js', array('jquery'), '1.0.11', true );
	}
	
	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'lontano_scripts' );

/**
 * Social Buttons
 */
if ( ! function_exists( 'lontano_social_buttons' ) ) {
	function lontano_social_buttons() {
		$facebookURL = get_theme_mod('lontano_theme_options_facebookurl', '');
		$twitterURL = get_theme_mod('lontano_theme_options_twitterurl', '');
		$googleplusURL = get_theme_mod('lontano_theme_options_googleplusurl', '');
		$linkedinURL = get_theme_mod('lontano_theme_options_linkedinurl', '');
		$instagramURL = get_theme_mod('lontano_theme_options_instagramurl', '');
		$youtubeURL = get_theme_mod('lontano_theme_options_youtubeurl', '');
		$pinterestURL = get_theme_mod('lontano_theme_options_pinteresturl', '');
		$tumblrURL = get_theme_mod('lontano_theme_options_tumblrurl', '');
		$vkURL = get_theme_mod('lontano_theme_options_vkurl', '');
		$wechatURL = get_theme_mod('lontano_theme_options_wechaturl', '');
		$weiboURL = get_theme_mod('lontano_theme_options_weibourl', '');
		$snapURL = get_theme_mod('lontano_theme_options_snapurl', '');
		$okruURL = get_theme_mod('lontano_theme_options_okruurl', '');
		$telegramURL = get_theme_mod('lontano_theme_options_telegramurl', '');
		$soundcloudURL = get_theme_mod('lontano_theme_options_soundcloudurl', '');
		if (!empty($facebookURL)) : ?>
			<a href="<?php echo esc_url($facebookURL); ?>" title="<?php esc_attr_e( 'Facebook', 'lontano' ); ?>"><i class="fa fa-facebook spaceLeftRight"><span class="screen-reader-text"><?php esc_html_e( 'Facebook', 'lontano' ); ?></span></i></a>
		<?php endif; ?>
		<?php if (!empty($twitterURL)) : ?>
			<a href="<?php echo esc_url($twitterURL); ?>" title="<?php esc_attr_e( 'Twitter', 'lontano' ); ?>"><i class="fa fa-twitter spaceLeftRight"><span class="screen-reader-text"><?php esc_html_e( 'Twitter', 'lontano' ); ?></span></i></a>
		<?php endif; ?>
		<?php if (!empty($googleplusURL)) : ?>
			<a href="<?php echo esc_url($googleplusURL); ?>" title="<?php esc_attr_e( 'Google Plus', 'lontano' ); ?>"><i class="fa fa-google-plus spaceLeftRight"><span class="screen-reader-text"><?php esc_html_e( 'Google Plus', 'lontano' ); ?></span></i></a>
		<?php endif; ?>
		<?php if (!empty($linkedinURL)) : ?>
			<a href="<?php echo esc_url($linkedinURL); ?>" title="<?php esc_attr_e( 'Linkedin', 'lontano' ); ?>"><i class="fa fa-linkedin spaceLeftRight"><span class="screen-reader-text"><?php esc_html_e( 'Linkedin', 'lontano' ); ?></span></i></a>
		<?php endif; ?>
		<?php if (!empty($instagramURL)) : ?>
			<a href="<?php echo esc_url($instagramURL); ?>" title="<?php esc_attr_e( 'Instagram', 'lontano' ); ?>"><i class="fa fa-instagram spaceLeftRight"><span class="screen-reader-text"><?php esc_html_e( 'Instagram', 'lontano' ); ?></span></i></a>
		<?php endif; ?>
		<?php if (!empty($youtubeURL)) : ?>
			<a href="<?php echo esc_url($youtubeURL); ?>" title="<?php esc_attr_e( 'YouTube', 'lontano' ); ?>"><i class="fa fa-youtube spaceLeftRight"><span class="screen-reader-text"><?php esc_html_e( 'YouTube', 'lontano' ); ?></span></i></a>
		<?php endif; ?>
		<?php if (!empty($pinterestURL)) : ?>
			<a href="<?php echo esc_url($pinterestURL); ?>" title="<?php esc_attr_e( 'Pinterest', 'lontano' ); ?>"><i class="fa fa-pinterest spaceLeftRight"><span class="screen-reader-text"><?php esc_html_e( 'Pinterest', 'lontano' ); ?></span></i></a>
		<?php endif; ?>
		<?php if (!empty($tumblrURL)) : ?>
			<a href="<?php echo esc_url($tumblrURL); ?>" title="<?php esc_attr_e( 'Tumblr', 'lontano' ); ?>"><i class="fa fa-tumblr spaceLeftRight"><span class="screen-reader-text"><?php esc_html_e( 'Tumblr', 'lontano' ); ?></span></i></a>
		<?php endif; ?>
		<?php if (!empty($vkURL)) : ?>
			<a href="<?php echo esc_url($vkURL); ?>" title="<?php esc_attr_e( 'VK', 'lontano' ); ?>"><i class="fa fa-vk spaceLeftRight"><span class="screen-reader-text"><?php esc_html_e( 'VK', 'lontano' ); ?></span></i></a>
		<?php endif; ?>
		<?php if (!empty($wechatURL)) : ?>
		<a href="<?php echo esc_url($wechatURL); ?>" title="<?php esc_attr_e( 'WeChat', 'lontano' ); ?>"><i class="fa fa-weixin spaceLeftRight"><span class="screen-reader-text"><?php esc_html_e( 'WeChat', 'lontano' ); ?></span></i></a>
		<?php endif; ?>
		<?php if (!empty($weiboURL)) : ?>
			<a href="<?php echo esc_url($weiboURL); ?>" title="<?php esc_attr_e( 'Weibo', 'lontano' ); ?>"><i class="fa fa-weibo spaceLeftRight"><span class="screen-reader-text"><?php esc_html_e( 'Weibo', 'lontano' ); ?></span></i></a>
		<?php endif; ?>
		<?php if (!empty($snapURL)) : ?>
			<a href="<?php echo esc_url($snapURL); ?>" title="<?php esc_attr_e( 'Snapchat', 'lontano' ); ?>"><i class="fa fa-snapchat spaceLeftRight"><span class="screen-reader-text"><?php esc_html_e( 'Snapchat', 'lontano' ); ?></span></i></a>
		<?php endif; ?>
		<?php if (!empty($okruURL)) : ?>
			<a href="<?php echo esc_url($okruURL); ?>" title="<?php esc_attr_e( 'OK.ru', 'lontano' ); ?>"><i class="fa fa-odnoklassniki spaceLeftRight"><span class="screen-reader-text"><?php esc_html_e( 'OK.ru', 'lontano' ); ?></span></i></a>
		<?php endif; ?>
		<?php if (!empty($telegramURL)) : ?>
			<a href="<?php echo esc_url($telegramURL); ?>" title="<?php esc_attr_e( 'Telegram', 'lontano' ); ?>"><i class="fa fa-telegram spaceLeftRight"><span class="screen-reader-text"><?php esc_html_e( 'Telegram', 'lontano' ); ?></span></i></a>
		<?php endif; ?>
		<?php if (!empty($soundcloudURL)) : ?>
			<a href="<?php echo esc_url($soundcloudURL); ?>" title="<?php esc_attr_e( 'SoundCloud', 'lontano' ); ?>"><i class="fa fa-soundcloud spaceLeftRight"><span class="screen-reader-text"><?php esc_html_e( 'SoundCloud', 'lontano' ); ?></span></i></a>
		<?php endif;
	}
}

/**
 * Replace Excerpt More
 */
if ( ! function_exists( 'lontano_new_excerpt_more' ) ) {
	function lontano_new_excerpt_more( $more ) {
		if ( is_admin() ) {
			return $more;
		}
		return '&hellip;';
	}
}
add_filter('excerpt_more', 'lontano_new_excerpt_more');

 /**
 * Delete font size style from tag cloud widget
 */
if ( ! function_exists( 'lontano_fix_tag_cloud' ) ) {
	function lontano_fix_tag_cloud($tag_string){
	   return preg_replace('/ style=("|\')(.*?)("|\')/','',$tag_string);
	}
}
add_filter('wp_generate_tag_cloud', 'lontano_fix_tag_cloud',10,1);

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Custom functions that act independently of the theme templates.
 */
require get_template_directory() . '/inc/extras.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/**
 * Load Jetpack compatibility file.
 */
if ( defined( 'JETPACK__VERSION' ) ) {
	require get_template_directory() . '/inc/jetpack.php';
}

/* Calling in the admin area for the Welcome Page */
if ( is_admin() ) {
	require get_template_directory() . '/inc/admin/lontano-admin-page.php';
}

/**
 * Load PRO Button in the customizer
 */
require_once( trailingslashit( get_template_directory() ) . 'inc/pro-button/class-customize.php' );